use strict;
use warnings;

use Plack::Request;
use LINE::Bot::API;
use LINE::Bot::API::Builder::SendMessage;

# Developer center から Channel Secret と Channel Access Token を入手してください
my $bot = LINE::Bot::API->new(
    channel_secret       => 'YOUR_SECRET',
    channel_access_token => 'YOUR_TOKEN',
);

sub {
    my $req = Plack::Request->new(shift);

    # 署名検証
    unless ($bot->validate_signature($req->content, $req->header('X-Line-Signature'))) {
        return [200, [], ['bad request']];
    }

    # イベントオブジェクトのパース
    my $events = $bot->parse_events_from_json($req->content);
    for my $event (@{ $events }) {
        if ($event->is_user_event && $event->is_message_event && $event->is_text_message) {
            # ユーザからテキストメッセージが送信された時だけ反応する

            # 返信用メッセージ組み立て
            my $messages = LINE::Bot::API::Builder::SendMessage->new
                ->add_text( text => $event->text );

            # 返信する
            my $res = $bot->reply_message($event->reply_token, $messages->build);

            # エラー発生時
            unless ($res->is_success) {
                my $msg = sprintf 'Error: code=%d, message=%s', $res->status_code, $res->status_message;
                warn $msg;
            }
        }
    }

    return [200, [], ["OK"]];
};
